==> haskell-tagstream-conduit-0.5.5.3-299-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagstream-conduit
version: 0.5.5.3
id: tagstream-conduit-0.5.5.3-DHrwmxCtnnCBHKJZIox1Lv
key: tagstream-conduit-0.5.5.3-DHrwmxCtnnCBHKJZIox1Lv
license: BSD-3-Clause
maintainer: yi.codeplayer@gmail.com
author: yihuang
homepage: http://github.com/yihuang/tagstream-conduit
synopsis: streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.
category: Web, Conduit
abi: 53caddc5a5b2acc23fca0839add9e88f
exposed: True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/tagstream-conduit-0.5.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/tagstream-conduit-0.5.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tagstream-conduit-0.5.5.3
hs-libraries: HStagstream-conduit-0.5.5.3-DHrwmxCtnnCBHKJZIox1Lv
depends:
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    conduit-1.3.1.1-KLNDZz0JwjY8UxgeaedHmp
    conduit-extra-1.3.4-D0NpH8QgZ19ARuWPauoeRr
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 text-1.2.3.1
    transformers-0.5.6.2 xml-conduit-1.8.0.1-ItKMKBLRSqtFuvW7keDBPV
haddock-interfaces: /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock
haddock-html: /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagstream-conduit-0.5.5.3-300-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagstream-conduit
version: 0.5.5.3
id: tagstream-conduit-0.5.5.3-FrVwgdyA9pCH3OlKPMpp77
key: tagstream-conduit-0.5.5.3-FrVwgdyA9pCH3OlKPMpp77
license: BSD-3-Clause
maintainer: yi.codeplayer@gmail.com
author: yihuang
homepage: http://github.com/yihuang/tagstream-conduit
synopsis: streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.
category: Web, Conduit
abi: 23add1aae9a7c9c7c180d56bb7f01025
exposed: True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/tagstream-conduit-0.5.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/tagstream-conduit-0.5.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tagstream-conduit-0.5.5.3
hs-libraries: HStagstream-conduit-0.5.5.3-FrVwgdyA9pCH3OlKPMpp77
depends:
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    conduit-1.3.1.1-7rushQ980336tJPFaKI7Kn
    conduit-extra-1.3.4-Hpz3g3HVeraCM2NDO7b1k4
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 text-1.2.3.1
    transformers-0.5.6.2 xml-conduit-1.8.0.1-5cZFy2zECMFJ5YEWhdhPDt
haddock-interfaces: /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock
haddock-html: /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
